//[mahjong-utils](../../../index.md)/[mahjongutils.hanhu](../index.md)/[ChildPoint](index.md)/[tsumoParent](tsumo-parent.md)

# tsumoParent

[common]\
val [tsumoParent](tsumo-parent.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

自摸亲家（庄家）点数
